.. pytextseg documentation back matter

References
==========

.. [CMOS] *The Chicago Manual of Style*, 15th edition.
   University of Chicago Press, 2003.

.. [JISX4051] JIS X 4051:2004
   *日本語文書の組版方法* (*Formatting Rules for Japanese Documents*).
   Japanese Standards Association, 2004.

.. [JLREQ] Anan, Yasuhiro et al.
  *Requirements for Japanese Text Layout*,
  W3C Working Draft 29 November 2011.
  <http://www.w3.org/TR/2011/WD-jlreq-20111129/>.

.. .. [Kubota]
   Kubota, Tomohiro (2001-2002).
   Width problems,
   "*Problems on Interoperativity between Unicode and CJK Local Encodings*".
   <http://web.archive.org/web/people.debian.org/~kubota/unicode-symbols-width2.html>.

.. [UAX11] A. Freytag (2008-2009).
   *Unicode Standard Annex #11: East Asian Width*, Revision 17-19.
   <http://unicode.org/reports/tr11/>.

.. [UAX14] A. Freytag and A. Heninger (2008-2012).
   *Unicode Standard Annex #14: Unicode Line Breaking Algorithm*, Revision 22-27.
   <http://unicode.org/reports/tr14/>.

.. [UAX29] Mark Davis (2009-2010).
   *Unicode Standard Annex #29: Unicode Text Segmentation*, Revision 15-17.
   <http://www.unicode.org/reports/tr29/>.

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

